@@ -1,5 +1,5 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: HTML-TEMPLATE; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/html-template/api.lisp,v 1.13 2003/07/15 19:07:52 edi Exp $
+;;; $Header: /usr/local/cvsrep/html-template/api.lisp,v 1.15 2005/07/03 11:13:52 edi Exp $
 
 ;;; Copyright (c) 2003, Dr. Edmund Weitz. All rights reserved.
 
@@ -35,10 +35,11 @@
                                           if-does-not-exist
                                           external-format)
   (:documentation "Creates a template printer from TEMPLATE which is
-an open input stream, a string, or a pathname. If FORCE is true a
+an open input stream, a string, or a pathname.  If FORCE is true a
 printer will be newly created no matter what the state of the cache
-is. Other keyword arguments will be given to WITH-OPEN-FILE. Keyword
-arguments will only be accepted if TEMPLATE is a PATHNAME."))
+is.  If FORCE is :DO-NOT-CACHE the newly created printer won't be
+cached.  Other keyword arguments will be given to WITH-OPEN-FILE.
+Keyword arguments will only be accepted if TEMPLATE is a PATHNAME."))
 
 (defmethod create-template-printer ((input-stream stream) &rest rest)
   (when rest
@@ -89,8 +90,9 @@ arguments will only be accepted if TEMPLATE is a PATHNAME."))
                                  :external-format external-format)
                   (%create-template-printer-aux nil nil)))))
         ;; cache newly created printer (together with current time)
-        (setf (gethash merged-pathname *printer-hash*)
-                (cons new-printer (get-universal-time)))
+        (unless (eq force :do-not-cache)
+          (setf (gethash merged-pathname *printer-hash*)
+                  (cons new-printer (get-universal-time))))
         ;; optionally issue a warning
         (when *warn-on-creation*
           (warn "New template printer for ~S created" merged-pathname))
@@ -113,7 +115,7 @@ used if TEMPLATE/PRINTER is a pathname."))
   (when rest
     (signal-template-invocation-error
      "This method doesn't accept keyword arguments other than STREAM"))
-  (let ((*standard-output* stream))
+  (let ((*template-output* stream))
     (funcall function values)))
 
 (defmethod fill-and-print-template ((string string) values
@@ -123,7 +125,7 @@ used if TEMPLATE/PRINTER is a pathname."))
   (when rest
     (signal-template-invocation-error
      "This method doesn't accept keyword arguments other than STREAM"))
-  (let ((*standard-output* stream))
+  (let ((*template-output* stream))
     (funcall (create-template-printer string) values)))
 
 (defmethod fill-and-print-template ((input-stream stream) values
@@ -133,14 +135,14 @@ used if TEMPLATE/PRINTER is a pathname."))
   (when rest
     (signal-template-invocation-error
      "This method doesn't accept keyword arguments other than STREAM"))
-  (let ((*standard-output* stream))
+  (let ((*template-output* stream))
     (funcall (create-template-printer input-stream) values)))
 
 (defmethod fill-and-print-template ((pathname pathname) values
                                     &rest rest
                                     &key (stream *default-template-output*))
   (remf rest :stream)
-  (let ((*standard-output* stream))
+  (let ((*template-output* stream))
     (funcall (apply #'create-template-printer pathname rest) values)))
 
 (defun clear-template-cache ()
