@@ -1,5 +1,5 @@
 ;;; -*- Mode: LISP; Syntax: COMMON-LISP; Package: HTML-TEMPLATE; Base: 10 -*-
-;;; $Header: /usr/local/cvsrep/html-template/template.lisp,v 1.15 2003/07/15 19:07:52 edi Exp $
+;;; $Header: /usr/local/cvsrep/html-template/template.lisp,v 1.17 2005/07/03 11:13:52 edi Exp $
 
 ;;; Copyright (c) 2003, Dr. Edmund Weitz. All rights reserved.
 
@@ -59,12 +59,12 @@ printed first."
       (null
         ;; no tag, just print STRING
         (lambda (values)
-          (write-string string)
+          (write-string string *template-output*)
           (funcall next-fn values)))
       (symbol
         ;; TMPL_VAR tag
         (lambda (values)
-          (write-string string)
+          (write-string string *template-output*)
           (write-string (let ((value (funcall *value-access-function*
                                               symbol/pathname values)))
                           (typecase value
@@ -82,12 +82,13 @@ printed first."
                                 (error 'template-not-a-string-error
                                        :value value
                                        :format-control "Value ~S for symbol ~S is not a string"
-                                       :format-arguments (list value symbol/pathname)))))))
+                                       :format-arguments (list value symbol/pathname))))))
+                        *template-output*)
           (funcall next-fn values)))
       (pathname
         ;; TMPL_INCLUDE tag
         (lambda (values)
-          (write-string string)
+          (write-string string *template-output*)
           (funcall (car (gethash symbol/pathname *printer-hash*)) values)
           (funcall next-fn values))))))
   
@@ -100,7 +101,7 @@ closures. STRING-LIST is a list of strings in reverse order to be
 printed first."
   (let ((string (list-to-string string-list)))
     (lambda (values)
-      (write-string string)
+      (write-string string *template-output*)
       (if (funcall *value-access-function* symbol values)
         (funcall if-fn values)
         (funcall else-fn values))
@@ -115,14 +116,14 @@ of strings in reverse order to be printed first."
   (let ((string (list-to-string string-list)))
     (cond (*sequences-are-lists*
             (lambda (values)
-              (write-string string)
+              (write-string string *template-output*)
               (dolist (value (funcall *value-access-function*
                                       symbol values))
                 (funcall loop-fn value))
               (funcall next-fn values)))
           (t
             (lambda (values)
-              (write-string string)
+              (write-string string *template-output*)
               (loop for value across (funcall *value-access-function*
                                               symbol values)
                     do (funcall loop-fn value))
